@@ -1,5 +1,5 @@
 from .abstractAccountKeysManager import *
-from .classesabstractInstructions import *
+from .abstractInstructionManager import *
 from .abstractLogMessages import *
 from .abstractTransactionProcessor import *
 from .abstractTxnManager import *
